# Generated by ariadne-codegen on 2024-01-01 10:41
# Source: operations.graphql

from typing import Optional

from pydantic import Field

from .base_model import BaseModel


class ReportUsageBulk(BaseModel):
    report_usage_bulk: Optional[str] = Field(alias="reportUsageBulk")


ReportUsageBulk.update_forward_refs()
